@@ -7,13 +7,12 @@ import os
 import fnmatch
 from pathlib import Path
 import requests
-from ocr import *
-from util import *
+from pyutilb import log, ocr_youdao
+from pyutilb.util import *
 import base64
-import util
-import validator
-import extractor
-from helpers import *
+from AppiumBoot.validator import Validator
+from AppiumBoot.extractor import Extractor
+from AppiumBoot.helpers import *
 
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support.select import Select
@@ -57,9 +56,9 @@ class Boot(object):
         # 基础url
         self._base_url = None
         # 当前页面的校验器
-        self.validator = validator.Validator(self.driver)
+        self.validator = Validator(self.driver)
         # 当前页面的提取器
-        self.extractor = extractor.Extractor(self.driver)
+        self.extractor = Extractor(self.driver)
         # 动作映射函数
         self.actions = {
             'init_driver': self.init_driver,
@@ -190,7 +189,7 @@ class Boot(object):
             step_file = os.path.abspath(step_file)
             self.step_dir = os.path.dirname(step_file)
 
-        print(f"加载并执行步骤文件: {step_file}")
+        log.debug(f"加载并执行步骤文件: {step_file}")
         # 获得步骤
         steps = read_yaml(step_file)
         try:
@@ -204,8 +203,8 @@ class Boot(object):
                 src = self.driver.page_source
                 # report_to_sauce(self.driver.session_id)
                 # take_screenshot_and_logcat(self.driver, device_logger, calling_request)
-            # print(f"异常环境:当前步骤文件为 {step_file}, 当前activity为 {activity}, 当前层级为 {src}")
-            print(f"异常环境:当前步骤文件为 {step_file}, 当前activity为 {activity}")
+            # log.debug(f"异常环境:当前步骤文件为 {step_file}, 当前activity为 {activity}, 当前层级为 {src}")
+            log.debug(f"异常环境:当前步骤文件为 {step_file}, 当前activity为 {activity}")
             raise ex
 
     # 执行多个步骤
@@ -253,7 +252,7 @@ class Boot(object):
             raise Exception(f'无效动作: [{action}]')
 
         # 调用动作对应的函数
-        print(f"处理动作: {action}={param}")
+        log.debug(f"处理动作: {action}={param}")
         func = self.actions[action]
         func(param)
 
@@ -300,17 +299,17 @@ class Boot(object):
         if n == None:
             n = sys.maxsize # 最大int，等于无限循环次数
             label = f"for(∞)"
-        print(f"-- 开始循环: {label} -- ")
+        log.debug(f"-- 开始循环: {label} -- ")
         try:
             for i in range(n):
                 # i+1表示迭代次数比较容易理解
-                print(f"第{i+1}次迭代")
+                log.debug(f"第{i+1}次迭代")
                 set_var('for_i', i+1)
                 self.run_steps(steps)
         except BreakException as e:  # 跳出循环
-            print(f"-- 跳出循环: {label}, 跳出条件: {e.condition} -- ")
+            log.debug(f"-- 跳出循环: {label}, 跳出条件: {e.condition} -- ")
         else:
-            print(f"-- 终点循环: {label} -- ")
+            log.debug(f"-- 终点循环: {label} -- ")
 
     # 执行一次子步骤，相当于 for(1)
     def once(self, steps):
@@ -323,7 +322,7 @@ class Boot(object):
 
     # 跳出for循环
     def break_if(self, expr):
-        val = eval(expr, globals(), util.vars)  # 丢失本地与全局变量, 如引用不了json模块
+        val = eval(expr, globals(), bvars)  # 丢失本地与全局变量, 如引用不了json模块
         if bool(val):
             raise BreakException(expr)
 
@@ -348,7 +347,7 @@ class Boot(object):
 
     # 打印变量
     def print_vars(self, _):
-        print(f"打印变量: {util.vars}")
+        log.info(f"打印变量: {bvars}")
 
     # 睡眠
     def sleep(self, seconds):
@@ -358,17 +357,17 @@ class Boot(object):
     # 打印
     def print(self, msg):
         msg = replace_var(msg)  # 替换变量
-        print(msg)
+        log.info(msg)
 
     # 解析响应
     def _analyze_response(self, res, config):
         # 添加固定变量:响应
         set_var('response', res)
         # 校验器
-        v = validator.Validator(self.driver, res)
+        v = Validator(self.driver, res)
         v.run(config)
         # 提取器
-        e = extractor.Extractor(self.driver, res)
+        e = Extractor(self.driver, res)
         e.run(config)
 
     # 根据组件id来填充输入框
@@ -396,7 +395,7 @@ class Boot(object):
     # :param input_data 表单数据, key是输入框的路径, value是填入的值
     def _input_by_type_and_data(self, type, input_data):
         for name, value in input_data.items():
-            print(f"替换变量： {name} = {value}")
+            log.debug(f"替换变量： {name} = {value}")
             value = replace_var(value)  # 替换变量
 
             # 找到输入框
@@ -836,7 +835,7 @@ class Boot(object):
         perfs = {}
         for type in types:
             perfs[type] = self.driver.get_performance_data(self.package, type)
-        print(perfs)
+        log.info(perfs)
 
     # 开始录屏
     def start_recording_screen(self, _):
@@ -883,7 +882,7 @@ class Boot(object):
                 'X-Requested-With': 'XMLHttpRequest'
             }
         res = requests.get(url, headers=headers, data=data)
-        # print(res.text)
+        # log.debug(res.text)
         # 解析响应
         self._analyze_response(res, config)
 
@@ -969,7 +968,7 @@ class Boot(object):
         # 设置变量
         set_var('download_file', save_file)
         self.downloaded_files[url] = save_file
-        print(f"下载文件: url为{url}, 另存为{save_file}")
+        log.debug(f"下载文件: url为{url}, 另存为{save_file}")
         return save_file
 
     # 识别url中的验证码
@@ -995,7 +994,7 @@ class Boot(object):
         captcha = ocr_youdao.recognize_text(file_path)
         # 设置变量
         set_var('captcha', captcha)
-        print(f"识别验证码: 图片为{file_path}, 验证码为{captcha}")
+        log.debug(f"识别验证码: 图片为{file_path}, 验证码为{captcha}")
         # 删除文件
         #os.remove(file)
 
